climind.readers package
=======================

Submodules
----------

climind.readers.generic\_reader module
--------------------------------------

.. automodule:: climind.readers.generic_reader
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_aviso module
------------------------------------

.. automodule:: climind.readers.reader_aviso
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_aviso\_ftp module
-----------------------------------------

.. automodule:: climind.readers.reader_aviso_ftp
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_badc\_csv module
----------------------------------------

.. automodule:: climind.readers.reader_badc_csv
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_berkeley module
---------------------------------------

.. automodule:: climind.readers.reader_berkeley
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_berkeley\_ts module
-------------------------------------------

.. automodule:: climind.readers.reader_berkeley_ts
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_cheng module
------------------------------------

.. automodule:: climind.readers.reader_cheng
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_clsat module
------------------------------------

.. automodule:: climind.readers.reader_clsat
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_cmems\_ph module
----------------------------------------

.. automodule:: climind.readers.reader_cmems_ph
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_era5 module
-----------------------------------

.. automodule:: climind.readers.reader_era5
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_gcos module
-----------------------------------

.. automodule:: climind.readers.reader_gcos
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_gistemp\_ts module
------------------------------------------

.. automodule:: climind.readers.reader_gistemp_ts
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_gml module
----------------------------------

.. automodule:: climind.readers.reader_gml
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_grace module
------------------------------------

.. automodule:: climind.readers.reader_grace
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_gsfc module
-----------------------------------

.. automodule:: climind.readers.reader_gsfc
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_hadcrut\_ts module
------------------------------------------

.. automodule:: climind.readers.reader_hadcrut_ts
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_hadsst\_ts module
-----------------------------------------

.. automodule:: climind.readers.reader_hadsst_ts
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_imbie module
------------------------------------

.. automodule:: climind.readers.reader_imbie
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_imbie\_2021\_antarctica module
------------------------------------------------------

.. automodule:: climind.readers.reader_imbie_2021_antarctica
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_imbie\_antarctica module
------------------------------------------------

.. automodule:: climind.readers.reader_imbie_antarctica
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_ipcc\_ts module
---------------------------------------

.. automodule:: climind.readers.reader_ipcc_ts
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_ishii module
------------------------------------

.. automodule:: climind.readers.reader_ishii
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_jra55 module
------------------------------------

.. automodule:: climind.readers.reader_jra55
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_kennaook module
---------------------------------------

.. automodule:: climind.readers.reader_kennaook
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_levitus module
--------------------------------------

.. automodule:: climind.readers.reader_levitus
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_mauna\_loa module
-----------------------------------------

.. automodule:: climind.readers.reader_mauna_loa
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_mhw\_ts module
--------------------------------------

.. automodule:: climind.readers.reader_mhw_ts
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_noaa\_interim\_ts module
------------------------------------------------

.. automodule:: climind.readers.reader_noaa_interim_ts
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_noaa\_ts module
---------------------------------------

.. automodule:: climind.readers.reader_noaa_ts
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_noaaglobaltemp module
---------------------------------------------

.. automodule:: climind.readers.reader_noaaglobaltemp
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_nsidc module
------------------------------------

.. automodule:: climind.readers.reader_nsidc
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_osisaf module
-------------------------------------

.. automodule:: climind.readers.reader_osisaf
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_promice module
--------------------------------------

.. automodule:: climind.readers.reader_promice
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_standard\_grid module
---------------------------------------------

.. automodule:: climind.readers.reader_standard_grid
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_test module
-----------------------------------

.. automodule:: climind.readers.reader_test
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_wdcgg\_rate\_ts module
----------------------------------------------

.. automodule:: climind.readers.reader_wdcgg_rate_ts
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_wdcgg\_ts module
----------------------------------------

.. automodule:: climind.readers.reader_wdcgg_ts
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_wdcgg\_ts\_update module
------------------------------------------------

.. automodule:: climind.readers.reader_wdcgg_ts_update
   :members:
   :undoc-members:
   :show-inheritance:

climind.readers.reader\_wgms module
-----------------------------------

.. automodule:: climind.readers.reader_wgms
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: climind.readers
   :members:
   :undoc-members:
   :show-inheritance:
